"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_1 = require("react");
/**
 *
 * Function to create a global state using React Context API,
 * which returns the ContextProvider and hooks to get the
 * state and updater function
 *
 * @param initialValue Initial value of the state
 */
function createSingleRhinoState(initialValue) {
    // Creating Context for state value & state updater function
    const ValueContext = React.createContext(initialValue);
    const UpdaterContext = react_1.createContext(() => null);
    /**
     *
     * React hook which returns the stateful value
     * @return Global State
     */
    const useStateValue = () => react_1.useContext(ValueContext);
    /**
     *
     * React hook which returns a function to update the global state
     * @return Global state updater function
     */
    const useStateUpdate = () => react_1.useContext(UpdaterContext);
    /**
     *
     * Provider Component which makes the state available to all the nested components
     */
    const Provider = ({ children }) => {
        const [state, setState] = react_1.useState(initialValue);
        return (React.createElement(ValueContext.Provider, { value: state },
            React.createElement(UpdaterContext.Provider, { value: setState }, children)));
    };
    return { Provider, useStateValue, useStateUpdate };
}
exports.default = createSingleRhinoState;
